/////////////////////////////////////////////////////////////////////////////
// Copyright (C) 1999 by Volker Voecking (VolkerVoecking@csi.com)
// All rights reserved
//
// Distribute freely, except: don't remove my name from the source or
// documentation (don't take credit for my work), mark your changes (don't
// get me blamed for your possible bugs), don't alter or remove this
// notice.
// No warrantee of any kind, express or implied, is included with this
// software; use at your own risk, responsibility for damages (if any) to
// anyone resulting from the use of this software rests entirely with the
// user.


/////////////////////////////////////////////////////////////////////////////
// ScrollViewPageCounter.cpp
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "SVPCSample.h"
#include "ScrollViewPageCounter.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CScrollViewPageCounter

BOOL CScrollViewPageCounter::s_bFirstCallDuringScrolling = TRUE;

CScrollViewPageCounter::CScrollViewPageCounter( CWnd *pParent )
{
   m_szPageNumber.Empty();
   m_lYPos = 0;
   CreateEx( WS_EX_TOPMOST, NULL, "", WS_POPUP | WS_CHILD | WS_BORDER, 
             300, 200, 20, 20, pParent->GetSafeHwnd(), 0, NULL );

}

CScrollViewPageCounter::~CScrollViewPageCounter()
{
}


BEGIN_MESSAGE_MAP(CScrollViewPageCounter, CWnd)
	//{{AFX_MSG_MAP(CScrollViewPageCounter)
	ON_WM_ERASEBKGND()
	ON_WM_PAINT()
	ON_WM_DESTROY()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()


/////////////////////////////////////////////////////////////////////////////

BOOL CScrollViewPageCounter::Create(LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext) 
{
	return CWnd::Create(lpszClassName, lpszWindowName, dwStyle, rect, pParentWnd, nID, pContext);
}

BOOL CScrollViewPageCounter::OnEraseBkgnd(CDC* pDC) 
{
   // Set brush to desired background color
   CBrush backBrush(RGB(255, 255, 200));      // yellow
   
   // Save old brush
   CBrush* pOldBrush = pDC->SelectObject(&backBrush);      
   
   CRect rect;
   pDC->GetClipBox(&rect);     // Erase the area needed
   pDC->PatBlt(rect.left, rect.top, rect.Width(), rect.Height(), PATCOPY);
   pDC->SelectObject(pOldBrush);      
   
   return TRUE;
}

void CScrollViewPageCounter::OnPaint() 
{
	CRect rect;
	GetClientRect(rect);

	CPaintDC dc(this);
	dc.SetTextAlign(TA_TOP | TA_CENTER);
	dc.SetTextColor(::GetSysColor(COLOR_WINDOWTEXT));
	dc.SetBkMode(TRANSPARENT);
   CSize size = dc.GetTextExtent( m_szPageNumber );

   dc.TextOut((rect.right / 2), ( rect.Height()-size.cy) / 2, m_szPageNumber);
}

void CScrollViewPageCounter::OnDestroy() 
{
	CWnd::OnDestroy();
   delete this;
}

void CScrollViewPageCounter::DisplayPageNumber( UINT uiPageNumber )
{
   CWnd* pWnd = GetParent();
   
   if ( pWnd )
   {
      // set y-position of the page number window
      if ( s_bFirstCallDuringScrolling )
      {
         POINT mousePosition;
         GetCursorPos( &mousePosition );
         m_lYPos = mousePosition.y;
      }
      
      // determine size and position of the view
      CRect rect;
      pWnd->GetClientRect( rect );
      pWnd->ClientToScreen( rect );
      
      // build the string that will be displayed
      m_szPageNumber.Format("Page %d", uiPageNumber);
      
      // adjust size and position of the window
      CPaintDC dc(this);
      int iWidth, iHeight;
      int xPos, yPos;
      
      CSize size = dc.GetTextExtent( m_szPageNumber );
      iWidth   = size.cx+10;
      iHeight  = size.cy+6;
      
      xPos = rect.right - iWidth - 30;
      yPos = m_lYPos - 10;
      
      SetWindowPos( NULL, xPos, yPos, iWidth, iHeight, SWP_NOOWNERZORDER );
      ShowWindow( SW_SHOW );
      
      RedrawWindow();
            
      s_bFirstCallDuringScrolling = FALSE;
   }
}  

void CScrollViewPageCounter::Reset()
{
   ShowWindow( SW_HIDE );
   s_bFirstCallDuringScrolling = TRUE;
}
